@@ -32,18 +32,18 @@ if ($arg =~ /(\d+)/) {
 }
 
 if (defined($new_x)) {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x,'SIMULATED_Y' => $new_y);
+    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 0, 'SIMULATED_X' => $new_x,'SIMULATED_Y' => $new_y);
 } else {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 1);
+    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 0);
 }
 
 $SIG{'QUIT'} = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
 $SIG{'INT'}  = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
 
-my $screen_width  = $F->{'XRES'};
-my $screen_height = $F->{'YRES'};
-my $xm            = $F->{'XRES'} / 1920;
-my $ym            = $F->{'YRES'} / 1080;
+my $screen_width  = $F->{'VXRES'};
+my $screen_height = $F->{'VYRES'};
+my $xm            = $F->{'VXRES'} / 1920;
+my $ym            = $F->{'VYRES'} / 1080;
 my $XX            = $screen_width;
 my $YY            = $screen_height;
 my $center_x      = $XX / 2;
@@ -57,8 +57,10 @@ $F->cls('OFF');
 # if (0) {
 color_mapping();
 plotting();
-lines();
-angle_lines();
+lines(0);
+lines(1);
+angle_lines(0);
+angle_lines(1);
 boxes();
 filled_boxes();
 vertical_gradient_boxes();
@@ -78,7 +80,10 @@ vertical_gradient_pies();
 # horizontal_gradient_pies();
 ellipses();
 filled_ellipses();
-polygons();
+vertical_gradient_ellipses();
+horizontal_gradient_ellipses();
+polygons(0);
+polygons(1);
 filled_polygons();
 vertical_gradient_polygons();
 # horizontal_gradient_polygons();
@@ -151,22 +156,32 @@ sub plotting {
 }
 
 sub lines {
-    print_it($F, 'Line Test');
+    my $aa = shift;
+    if ($aa) {
+        print_it($F, 'Antialiased Line Test');
+    } else {
+        print_it($F, 'Line Test');
+    }
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-        $F->line({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY)});
+        $F->line({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY),'antialiased'=>$aa});
     }
 }
 
 sub angle_lines {
-    print_it($F, 'Angle Line Test');
+    my $aa = shift;
+    if ($aa) {
+        print_it($F, 'Antialiased Angle Line Test');
+    } else {
+        print_it($F, 'Angle Line Test');
+    }
 
     my $s = time + $factor;
     my $angle = 0;
     while (time < $s) {
         $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-        $F->angle_line({'x' => $center_x, 'y' => $center_y, 'radius' => ($center_y - $F->{'Y_CLIP'}), 'angle' => $angle});
+        $F->angle_line({'x' => $center_x, 'y' => $center_y, 'radius' => ($center_y - $F->{'Y_CLIP'}), 'angle' => $angle,'antialiased'=>$aa});
         $angle += 1.1;
         $angle -= 360 if ($angle >= 360);
     }
@@ -536,12 +551,17 @@ sub horizontal_gradient_ellipses {
 }
 
 sub polygons {
-    print_it($F, 'Polygon Test');
+    my $aa = shift;
+    if ($aa) {
+        print_it($F, 'Antialiased Polygon Test');
+    } else {
+        print_it($F, 'Polygon Test');
+    }
 
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-        $F->polygon({'coordinates' => [rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY)]});
+        $F->polygon({'coordinates' => [rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY), rand($XX), rand($YY)],'antialiased' => $aa});
     }
 }
 
@@ -618,10 +638,10 @@ sub truetype_fonts {
     print_it($F, 'Testing TrueType Font Rendering (random height/width)');
 
     my @fonts = (keys %{$F->{'FONTS'}});
-    my $g = time + $factor * 2;
+    my $g = time + $factor;
     while (time < $g) {
         my $x  = int(rand(600 * $xm));
-        my $y  = int(rand(900 * $ym));
+        my $y  = int(rand(1080 * $ym));
         my $h  = ($YY <= 240 || $F->{'BITS'} == 16) ? (6 + rand(60)) : (8 + int(rand(300 * $ym)));
         my $ws = ($XX <= 320 || $F->{'BITS'} == 16) ? rand(2) : rand(4);
         my $font = $fonts[int(rand(scalar(@fonts)))];
@@ -632,7 +652,7 @@ sub truetype_fonts {
                 'height'       => $h,
                 'wscale'       => $ws,
                 'color'        => sprintf('%02x%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256)),255),
-                'text'         => 'GFB',
+                'text'         => $font,
                 'font_path'    => $F->{'FONTS'}->{$font}->{'path'},
                 'face'         => $F->{'FONTS'}->{$font}->{'font'},
                 'bounding_box' => 1,
@@ -686,12 +706,16 @@ sub color_replace_with_clipping {
         my $B = int(rand(256));
         $F->replace_color(
             {
-                'old_red'   => $r,
-                'old_green' => $g,
-                'old_blue'  => $b,
-                'new_red'   => $R,
-                'new_green' => $G,
-                'new_blue'  => $B
+                'old' => {
+                    'red'   => $r,
+                    'green' => $g,
+                    'blue'  => $b
+                },
+                'new' => {
+                    'red'   => $R,
+                    'green' => $G,
+                    'blue'  => $B
+                }
             }
         );
         ($r, $g, $b) = ($R, $G, $B);
@@ -715,12 +739,16 @@ sub color_replace_no_clipping {
         my $B = int(rand(256));
         $F->replace_color(
             {
-                'old_red'   => $r,
-                'old_green' => $g,
-                'old_blue'  => $b,
-                'new_red'   => $R,
-                'new_green' => $G,
-                'new_blue'  => $B
+                'old' => {
+                    'red'   => $r,
+                    'green' => $g,
+                    'blue'  => $b
+                },
+                'new' => {
+                    'red'   => $R,
+                    'green' => $G,
+                    'blue'  => $B
+                }
             }
         );
         ($r, $g, $b) = ($R, $G, $B);
