@@ -58,3 +58,36 @@ if (ref($image) eq 'ARRAY') {
 sleep 3;
 $f->cls('ON');
 
+=head1 NAME
+
+Picture View
+
+=head1 DESCRIPTION
+
+Single image (or animation) viewer
+
+=head1 SYNOPISIS
+
+ perl viewpic.pl [file] [device number] [full] "path to image"
+
+=head1 OPTIONS
+
+Like the name implies, these are all optional, and can be entered in any order, EXCEPT for the file path.
+
+=over 2
+
+=item C<device Number> (just the number)
+
+A number from 0 - 31 indicating which framebuffer device to render to
+
+=item C<file>
+
+Tells it to render in file handle mode instead of memory mapped string mode.
+
+=item C<full>
+
+Tells it to scale (proportionally) all images (and animations) to full screen.
+
+=back
+
+=cut
